@@ -1,23 +1,29 @@
 /*
  * ark -- archiver for the KDE project
  *
- * Copyright (C) 2008 Harald Hvaal <haraldhv atatatat stud.ntnu.no>
+ * Copyright (C) 2008 Harald Hvaal <haraldhv@stud.ntnu.no>
  * Copyright (C) 2009 Raphael Kubo da Costa <kubito@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include "adddialog.h"
@@ -28,6 +34,7 @@
 #include <KFilePlacesModel>
 #include <KGlobal>
 
+#include <QFileInfo>
 #include <QStandardItemModel>
 
 namespace Kerfuffle
@@ -62,6 +69,11 @@ AddDialog::AddDialog(const QStringList& itemsToAdd,
 
     setupIconList(itemsToAdd);
 
+    // Set up a default name if there's only one file to compress
+    if (itemsToAdd.size() == 1) {
+        setSelection(QFileInfo(itemsToAdd.first()).baseName());
+    }
+
     //These extra options will be implemented in a 4.2+ version of
     //ark
     m_ui->groupExtraOptions->hide();
@@ -71,14 +83,15 @@ void AddDialog::loadConfiguration()
 {
     m_config = KConfigGroup(KGlobal::config()->group("AddDialog"));
 
-    QString defaultMimeType = "application/x-compressed-tar";
-    QStringList writeMimeTypes = Kerfuffle::supportedWriteMimeTypes();
-    QString lastMimeType = m_config.readEntry("LastMimeType", defaultMimeType);
+    const QString defaultMimeType = QLatin1String( "application/x-compressed-tar" );
+    const QStringList writeMimeTypes = Kerfuffle::supportedWriteMimeTypes();
+    const QString lastMimeType = m_config.readEntry("LastMimeType", defaultMimeType);
 
-    if (writeMimeTypes.contains(lastMimeType))
+    if (writeMimeTypes.contains(lastMimeType)) {
         setMimeFilter(writeMimeTypes, lastMimeType);
-    else
+    } else {
         setMimeFilter(writeMimeTypes, defaultMimeType);
+    }
 }
 
 void AddDialog::setupIconList(const QStringList& itemsToAdd)
