@@ -60,30 +60,34 @@ public:
 
     static bool compareAscending(const QPair<ArchiveNode*,int> &a, const QPair<ArchiveNode*,int> &b) {
         // #234373: sort folders before files
-        if (a.first->isDir() != b.first->isDir())
+        if (a.first->isDir() != b.first->isDir()) {
             return a.first->isDir();
+        }
 
-        if (currentSortColumn == FileName)
+        if (currentSortColumn == FileName) {
             return (a.first->m_name < b.first->m_name);
-        else if ((currentSortColumn == Size) ||
-                 (currentSortColumn == CompressedSize))
+        } else if ((currentSortColumn == Size) ||
+                   (currentSortColumn == CompressedSize)) {
             return (a.first->entry()[currentSortColumn].toInt() < b.first->entry()[currentSortColumn].toInt());
-        else
+        } else {
             return (a.first->entry()[currentSortColumn].toString() < b.first->entry()[currentSortColumn].toString());
+        }
     }
 
     static bool compareDescending(const QPair<ArchiveNode*,int> &a, const QPair<ArchiveNode*,int> &b) {
         // #234373: sort folders before files
-        if (a.first->isDir() != b.first->isDir())
+        if (a.first->isDir() != b.first->isDir()) {
             return !(a.first->isDir());
+        }
 
-        if (currentSortColumn == FileName)
+        if (currentSortColumn == FileName) {
             return (a.first->m_name > b.first->m_name);
-        else if ((currentSortColumn == Size) ||
-                 (currentSortColumn == CompressedSize))
+        } else if ((currentSortColumn == Size) ||
+                   (currentSortColumn == CompressedSize)) {
             return (a.first->entry()[currentSortColumn].toInt() > b.first->entry()[currentSortColumn].toInt());
-        else
+        } else {
             return (a.first->entry()[currentSortColumn].toString() > b.first->entry()[currentSortColumn].toString());
+        }
     }
 
     const ArchiveEntry &entry() const {
@@ -92,7 +96,7 @@ public:
     void setEntry(const ArchiveEntry& entry) {
         m_entry = entry;
 
-        const QStringList pieces = entry[FileName].toString().split('/', QString::SkipEmptyParts);
+        const QStringList pieces = entry[FileName].toString().split(QLatin1Char( '/' ), QString::SkipEmptyParts);
         m_name = pieces.isEmpty() ? QString() : pieces.last();
     }
 
@@ -129,7 +133,7 @@ class ArchiveDirNode: public ArchiveNode
 public:
     ArchiveDirNode(ArchiveDirNode *parent, const ArchiveEntry & entry)
             : ArchiveNode(parent, entry) {
-        m_icon = KIconLoader::global()->loadMimeTypeIcon(KMimeType::mimeType("inode/directory")->iconName(), KIconLoader::Small);
+        m_icon = KIconLoader::global()->loadMimeTypeIcon(KMimeType::mimeType(QLatin1String( "inode/directory" ))->iconName(), KIconLoader::Small);
     }
 
 
@@ -250,7 +254,7 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
                         return QVariant();
                     } else {
                         int ratio = int(100 * ((double)size - compressedSize) / size);
-                        return QString::number(ratio) + " %";
+                        return QString::number(ratio) + QLatin1String( " %" );
                     }
                 }
 
@@ -410,8 +414,9 @@ int ArchiveModel::columnCount(const QModelIndex &parent) const
 
 void ArchiveModel::sort(int column, Qt::SortOrder order)
 {
-    if (m_showColumns.size() <= column)
+    if (m_showColumns.size() <= column) {
         return;
+    }
 
     currentSortColumn = m_showColumns.at(column);
 
@@ -429,10 +434,11 @@ void ArchiveModel::sort(int column, Qt::SortOrder order)
             sorting[i].second = i;
         }
 
-        if (order == Qt::AscendingOrder)
+        if (order == Qt::AscendingOrder) {
             qSort(sorting.begin(), sorting.end(), ArchiveNode::compareAscending);
-        else
+        } else {
             qSort(sorting.begin(), sorting.end(), ArchiveNode::compareDescending);
+        }
 
         QModelIndexList fromIndexes;
         QModelIndexList toIndexes;
@@ -462,42 +468,44 @@ QStringList ArchiveModel::mimeTypes() const
 {
     QStringList types;
 
-    types << QString("text/uri-list")
-    << QString("text/plain")
-    << QString("text/x-moz-url")
-    << QString("application/x-kde-urilist")
-    << QString("application/x-kde-extractdrag");
+    types << QLatin1String("text/uri-list")
+    << QLatin1String("text/plain")
+    << QLatin1String("text/x-moz-url")
+    << QLatin1String("application/x-kde-urilist")
+    << QLatin1String("application/x-kde-extractdrag");
 
     return types;
 }
 
 QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
 {
-    kDebug() ;
+    kDebug();
     //prepare the fallback kio_slave filenames
     QStringList files;
     bool noFallback = false;
 
     QString archiveName = m_archive->fileName();
     QString ext = QFileInfo(archiveName).suffix().toUpper();
-    if (ext == "TAR") {
-        archiveName.prepend("tar:");
-    } else if (ext == "ZIP") {
-        archiveName.prepend("zip:");
-    } else if (archiveName.right(6).toUpper() == "TAR.GZ") {
-        archiveName.prepend("tar:");
+    if (ext == QLatin1String( "TAR" )) {
+        archiveName.prepend(QLatin1String( "tar:" ));
+    } else if (ext == QLatin1String( "ZIP" )) {
+        archiveName.prepend(QLatin1String( "zip:" ));
+    } else if (archiveName.right(6).toUpper() == QLatin1String( "TAR.GZ" )) {
+        archiveName.prepend(QLatin1String( "tar:" ));
     } else
         noFallback = true;
 
-    if (!archiveName.endsWith('/')) {
-        archiveName.append('/');
+    if (!archiveName.endsWith(QLatin1Char( '/' ))) {
+        archiveName.append(QLatin1Char( '/' ));
     }
 
     //Populate the internal list of files
     foreach(const QModelIndex &index, indexes) {
 
         //to limit only one index per row
-        if (index.column() != 0) continue;
+        if (index.column() != 0) {
+            continue;
+        }
 
         const QString file = archiveName + static_cast<ArchiveNode*>(index.internalPointer())->entry()[ FileName ].toString();
         files << file;
@@ -507,13 +515,14 @@ QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
 
     //prepare the dbus-based drag/drop mimedata
     QMimeData *data = new QMimeData();
-    data->setData("application/x-kde-dndextract",
+    data->setData(QLatin1String( "application/x-kde-dndextract" ),
                   QDBusConnection::sessionBus().baseService().toUtf8()
                  );
 
 
-    if (!noFallback)
+    if (!noFallback) {
         kiolist.populateMimeData(data);
+    }
     return data;
 }
 
@@ -524,8 +533,9 @@ bool ArchiveModel::dropMimeData(const QMimeData * data, Qt::DropAction action, i
     Q_UNUSED(column)
     Q_UNUSED(parent)
 
-    if (!data->hasUrls())
+    if (!data->hasUrls()) {
         return false;
+    }
 
     QStringList paths;
     foreach(const QUrl &url, data->urls()) {
@@ -572,16 +582,16 @@ QString ArchiveModel::cleanFileName(const QString& fileName)
 
 ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
 {
-    QStringList pieces = entry[ FileName ].toString().split('/', QString::SkipEmptyParts);
-    if (pieces.isEmpty()) return NULL;
+    QStringList pieces = entry[ FileName ].toString().split(QLatin1Char( '/' ), QString::SkipEmptyParts);
+    if (pieces.isEmpty()) {
+        return NULL;
+    }
     pieces.removeLast();
 
     if (previousMatch) {
-
         //the number of path elements must be the same for the shortcut
         //to work
         if (previousPieces.count() == pieces.count()) {
-
             bool equal = true;
 
             //make sure all the pieces match up
@@ -595,10 +605,8 @@ ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
             //if match return it
             if (equal) {
                 return static_cast<ArchiveDirNode*>(previousMatch);
-
             }
         }
-
     }
 
     ArchiveDirNode *parent = m_rootNode;
@@ -608,7 +616,7 @@ ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
         if (!node) {
             ArchiveEntry e;
             e[ FileName ] = (parent == m_rootNode) ?
-                            piece : parent->entry()[ FileName ].toString() + '/' + piece;
+                            piece : parent->entry()[ FileName ].toString() + QLatin1Char( '/' ) + piece;
             e[ IsDirectory ] = true;
             node = new ArchiveDirNode(parent, e);
             insertNode(node);
@@ -648,7 +656,7 @@ void ArchiveModel::slotEntryRemoved(const QString & path)
         return;
     }
 
-    ArchiveNode *entry = m_rootNode->findByPath(entryFileName.split('/', QString::SkipEmptyParts));
+    ArchiveNode *entry = m_rootNode->findByPath(entryFileName.split(QLatin1Char( '/' ), QString::SkipEmptyParts));
     if (entry) {
         ArchiveDirNode *parent = entry->parent();
         QModelIndex index = indexForNode(entry);
@@ -694,7 +702,6 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
     //if there are no addidional columns registered, then have a look at the
     //entry and populate some
     if (m_showColumns.isEmpty()) {
-
         //these are the columns we are interested in showing in the display
         static const QList<int> columnsForDisplay =
             QList<int>()
@@ -714,15 +721,15 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
         QList<int> toInsert;
 
         foreach(int column, columnsForDisplay) {
-            if (receivedEntry.contains(column))
+            if (receivedEntry.contains(column)) {
                 toInsert << column;
+            }
         }
         beginInsertColumns(QModelIndex(), 0, toInsert.size() - 1);
         m_showColumns << toInsert;
         endInsertColumns();
 
         kDebug() << "Show columns detected: " << m_showColumns;
-
     }
 
     //make a copy
@@ -738,7 +745,7 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
 
     /// 1. Skip already created nodes
     if (m_rootNode) {
-        ArchiveNode *existing = m_rootNode->findByPath(entry[ FileName ].toString().split('/'));
+        ArchiveNode *existing = m_rootNode->findByPath(entry[ FileName ].toString().split(QLatin1Char( '/' )));
         if (existing) {
             kDebug() << "Refreshing entry for" << entry[FileName].toString();
 
@@ -757,12 +764,12 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
     ArchiveDirNode *parent = parentFor(entry);
 
     /// 3. Create an ArchiveNode
-    QString name = entry[ FileName ].toString().split('/', QString::SkipEmptyParts).last();
+    QString name = entry[ FileName ].toString().split(QLatin1Char( '/' ), QString::SkipEmptyParts).last();
     ArchiveNode *node = parent->find(name);
     if (node) {
         node->setEntry(entry);
     } else {
-        if (entry[ FileName ].toString().endsWith('/') || (entry.contains(IsDirectory) && entry[ IsDirectory ].toBool())) {
+        if (entry[ FileName ].toString().endsWith(QLatin1Char( '/' )) || (entry.contains(IsDirectory) && entry[ IsDirectory ].toBool())) {
             node = new ArchiveDirNode(parent, entry);
         } else {
             node = new ArchiveNode(parent, entry);
@@ -788,9 +795,13 @@ void ArchiveModel::insertNode(ArchiveNode *node, InsertBehaviour behaviour)
     Q_ASSERT(node);
     ArchiveDirNode *parent = node->parent();
     Q_ASSERT(parent);
-    if (behaviour == NotifyViews) beginInsertRows(indexForNode(parent), parent->entries().count(), parent->entries().count());
+    if (behaviour == NotifyViews) {
+        beginInsertRows(indexForNode(parent), parent->entries().count(), parent->entries().count());
+    }
     parent->entries().append(node);
-    if (behaviour == NotifyViews) endInsertRows();
+    if (behaviour == NotifyViews) {
+        endInsertRows();
+    }
 }
 
 Kerfuffle::Archive* ArchiveModel::archive() const
@@ -849,7 +860,9 @@ ExtractJob* ArchiveModel::extractFiles(const QList<QVariant>& files, const QStri
 
 AddJob* ArchiveModel::addFiles(const QStringList & filenames, const CompressionOptions& options)
 {
-    if (!m_archive) return NULL;
+    if (!m_archive) {
+        return NULL;
+    }
 
     if (!m_archive->isReadOnly()) {
         AddJob *job = m_archive->addFiles(filenames, options);
