@@ -192,7 +192,11 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
     bool skipAll = false; // Whether to skip all files
     struct archive_entry *entry;
 
+    QString fileBeingRenamed;
+
     while (archive_read_next_header(arch.data(), &entry) == ARCHIVE_OK) {
+        fileBeingRenamed.clear();
+
         // retry with renamed entry, fire an overwrite query again
         // if the new entry also exists
     retry:
@@ -215,13 +219,13 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
             return false;
         }
 
-        if (files.contains(entryName) || extractAll) {
+        if (files.contains(entryName) || entryName == fileBeingRenamed || extractAll) {
             // entryFI is the fileinfo pointing to where the file will be
             // written from the archive
             QFileInfo entryFI(entryName);
             //kDebug() << "setting path to " << archive_entry_pathname( entry );
 
-            QString fileWithoutPath = entryFI.fileName();
+            const QString fileWithoutPath(entryFI.fileName());
 
             //if we DON'T preserve paths, we cut the path and set the entryFI
             //fileinfo to the one without the path
@@ -236,9 +240,9 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
                 //OR, if the commonBase has been set, then we remove this
                 //common base from the filename
             } else if (!rootNode.isEmpty()) {
-                QString truncatedFilename;
-                truncatedFilename = entryName.remove(0, rootNode.size());
+                const QString truncatedFilename(entryName.remove(0, rootNode.size()));
                 kDebug() << "Truncated filename: " << truncatedFilename;
+
                 archive_entry_copy_pathname(entry, QFile::encodeName(truncatedFilename).constData());
 
                 entryFI = QFileInfo(truncatedFilename);
@@ -269,7 +273,8 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
                         skipAll = true;
                         continue;
                     } else if (query.responseRename()) {
-                        QString newName = query.newFilename();
+                        const QString newName(query.newFilename());
+                        fileBeingRenamed = newName;
                         archive_entry_copy_pathname(entry, QFile::encodeName(newName).constData());
                         goto retry;
                     } else if (query.responseOverwriteAll()) {
