@@ -3,7 +3,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -44,7 +44,7 @@ KCharSelectDia::KCharSelectDia()
   vFont = gr.readEntry("selectedFont", KGlobalSettings::generalFont());
   vChr = QChar(static_cast<unsigned short>(gr.readEntry("char", 33)));
   _rtl = gr.readEntry("rtl", false);
-  
+
   QWidget *mainWidget = new QWidget(this);
   setCentralWidget(mainWidget);
 
@@ -53,7 +53,7 @@ KCharSelectDia::KCharSelectDia()
   grid->setSpacing( KDialog::spacingHint() );
 
   // Add character selection widget from library kdeui
-  charSelect = new KCharSelect(mainWidget);
+  charSelect = new KCharSelect(mainWidget, actionCollection());
   charSelect->setCurrentChar(vChr);
   charSelect->setCurrentFont(vFont);
   charSelect->resize(charSelect->sizeHint());
@@ -77,7 +77,7 @@ KCharSelectDia::KCharSelectDia()
   grid->addWidget(lined, 1, 0, 1, 3);
 
   bClip = new KPushButton( KGuiItem( i18n( "&To Clipboard" ),
-            "edit-copy" ), mainWidget );
+            QLatin1String( "edit-copy" ) ), mainWidget );
   bClip->setFixedSize( bClip->sizeHint() );
   connect(bClip,SIGNAL(clicked()),this,SLOT(toClip()));
   grid->addWidget(bClip, 1, 3);
@@ -85,37 +85,37 @@ KCharSelectDia::KCharSelectDia()
   // Build menu
   KStandardAction::quit( this, SLOT(close()), actionCollection() );
 
-  QAction *action = actionCollection()->addAction( "copy_clip" );
+  KAction *action = actionCollection()->addAction( QLatin1String( "copy_clip" ) );
   action->setText( i18n("&To Clipboard") );
-  action->setIcon( KIcon("edit-copy") );
+  action->setIcon( KIcon( QLatin1String( "edit-copy" )) );
   connect(action, SIGNAL(triggered(bool)), SLOT(toClip()));
   action->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Copy));
 
-  action = actionCollection()->addAction( "copy_utf_8" );
+  action = actionCollection()->addAction( QLatin1String( "copy_utf_8" ) );
   action->setText( i18n("To Clipboard &UTF-8") );
   connect(action, SIGNAL(triggered(bool) ), SLOT(toClipUTF8()));
-  action = actionCollection()->addAction( "copy_html" );
+  action = actionCollection()->addAction( QLatin1String( "copy_html" ) );
   action->setText( i18n("To Clipboard &HTML") );
   connect(action, SIGNAL(triggered(bool) ), SLOT(toClipHTML()));
 
-  action = actionCollection()->addAction( "from_clip" );
+  action = actionCollection()->addAction( QLatin1String( "from_clip" ) );
   action->setText( i18n("&From Clipboard") );
-  action->setIcon( KIcon("edit-paste") );
+  action->setIcon( KIcon( QLatin1String( "edit-paste" )) );
   connect(action, SIGNAL(triggered(bool)), SLOT(fromClip()));
   action->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Paste));
-  action = actionCollection()->addAction( "from_clip_utf8" );
+  action = actionCollection()->addAction( QLatin1String( "from_clip_utf8" ) );
   action->setText( i18n( "From Clipboard UTF-8") );
   connect(action, SIGNAL(triggered(bool) ), SLOT(fromClipUTF8()));
 
   i18n("From Clipboard HTML");      // Intended for future use
 
-  action = actionCollection()->addAction( "flip" );
+  action = actionCollection()->addAction( QLatin1String( "flip" ) );
   action->setText( i18n("&Flip Text") );
   connect(action, SIGNAL(triggered(bool) ), SLOT(flipText()));
 
   action = new KToggleAction( i18n("&Reverse Direction"), this );
   action->setChecked(_rtl);
-  actionCollection()->addAction( "rtl", action );
+  actionCollection()->addAction( QLatin1String( "rtl" ), action );
   connect(action, SIGNAL(toggled(bool) ), SLOT(setRtl(bool)));
 
   charSelect->setFocus();
@@ -125,7 +125,7 @@ KCharSelectDia::KCharSelectDia()
   else
     lined->setAlignment( Qt::AlignLeft );
 
-  setupGUI(Keys|Save|Create);
+  setupGUI(ToolBar|Keys|Save|Create);
 }
 
 //==================================================================
@@ -161,7 +161,7 @@ void KCharSelectDia::add(const QChar &_chr)
   charChanged(_chr);
 
   QString str = lined->text();
-  int pos = lined->cursorPosition();
+  const int pos = lined->cursorPosition();
   str.insert(pos, _chr);
   lined->setText(str);
   lined->setCursorPosition(pos + 1);
@@ -182,8 +182,8 @@ void KCharSelectDia::toClip()
 void KCharSelectDia::toClipUTF8()
 {
   QClipboard *cb = QApplication::clipboard();
-  QString str = lined->text();
-  cb->setText(str.toUtf8());
+  const QString str = lined->text();
+  cb->setText(QLatin1String( str.toUtf8() ));
 }
 
 //==================================================================
@@ -199,10 +199,11 @@ void KCharSelectDia::toClipHTML()
   QString html;
   QString tempstring;
   QChar   tempchar;
-  int i;
+  int i = 0;
 
   input = lined->text();
-  for(i=0; i< input.length(); i++ )
+  const int inputLength = input.length();
+  for(i=0; i< inputLength; ++i )
     {
       tempchar = input.at(i);
       if(  tempchar.toLatin1() && ((tempchar.unicode() < 128) || (tempchar.unicode() >= 128+32)) )
@@ -234,7 +235,7 @@ void KCharSelectDia::fromClip()
 void KCharSelectDia::fromClipUTF8()
 {
   QClipboard *cb = QApplication::clipboard();
-  QString str = cb->text();
+  const QString str = cb->text();
 
   lined->setText( str.fromUtf8( str.toLatin1() ) );
 }
@@ -252,7 +253,8 @@ void KCharSelectDia::flipText()
   int i;
 
   input = lined->text();
-  for(i=0; i< input.length(); i++ )
+  const int nbLength = input.length();
+  for(i=0; i< nbLength; ++i )
     {
       output.prepend( input.at(i) );
     }
