@@ -37,7 +37,7 @@
 static const char description[] =
     I18N_NOOP("KDE free disk space utility");
 
-static const char version[] = "v0.11"; //bump version ?
+static const char version[] = "v0.12"; //bump version ?
 
 
 /***************************************************************/
@@ -46,7 +46,7 @@ KDFTopLevel::KDFTopLevel(QWidget *)
 {
     kdf = new KDFWidget(this,false);
     Q_CHECK_PTR(kdf);
-    QAction *action = actionCollection()->addAction( "updatedf" );
+    QAction *action = actionCollection()->addAction( QLatin1String( "updatedf" ));
     action->setText( i18nc( "Update action", "&Update" ) );
     connect(action, SIGNAL(triggered(bool) ), kdf, SLOT( updateDF() ));
 
