@@ -249,7 +249,7 @@ void KgpgTextEdit::slotDecryptDone(int result)
 #ifdef __GNUC__
 #warning FIXME choose codec
 #endif
-		setPlainText(decr->decryptedText().join( QLatin1String( "\n" )));
+		setPlainText(decr->decryptedText().join(QLatin1String("\n")) + QLatin1Char('\n'));
 	} else if (result != KGpgTransaction::TS_USER_ABORTED) {
 		KMessageBox::detailedSorry(this, i18n("Decryption failed."), decr->getMessages().join( QLatin1String( "\n" )));
 	}
