@@ -23,7 +23,6 @@
 #include <KCmdLineArgs>
 #include <KMessageBox>
 #include <KWindowSystem>
-#include <KActionCollection>
 #include <KMimeType>
 
 #include "images.h"
@@ -32,7 +31,8 @@
 #include "keysmanager.h"
 #include "kgpg_interface.h"
 #include "kgpgexternalactions.h"
-#include "kgpgview.h"
+#include "kgpgimport.h"
+#include "kgpginterface.h"
 
 using namespace KgpgCore;
 
@@ -57,7 +57,7 @@ void KGpgApp::slotHandleQuit()
 
 void KGpgApp::assistantOver(const QString &defaultKeyId)
 {
-	if (defaultKeyId.length() >= 8)
+	if (!defaultKeyId.isEmpty())
 		s_keyManager->slotSetDefaultKey(defaultKeyId);
 
 	s_keyManager->show();
@@ -69,14 +69,13 @@ int KGpgApp::newInstance()
 	if (!running) {
 		running = true;
 
-		s_keyManager = new KeysManager();
-
 		const QString gpgPath(KGpgSettings::gpgConfigPath());
 		if (!gpgPath.isEmpty())
-			if (KUrl::fromPath(gpgPath).directory(KUrl::AppendTrailingSlash) != (QDir::homePath() + "/.gnupg/"))
+			if (KUrl::fromPath(gpgPath).directory(KUrl::AppendTrailingSlash) != (QDir::homePath() + QLatin1String( "/.gnupg/" )))
 				setenv("GNUPGHOME", KUrl::fromPath(gpgPath).directory(KUrl::AppendTrailingSlash).toAscii(), 1);
 
-		s_keyManager->refreshkey();
+		s_keyManager = new KeysManager();
+
 		w = new KGpgExternalActions(s_keyManager, s_keyManager->getModel());
 		connect(w, SIGNAL(importDrop(const QString &)), s_keyManager, SLOT(slotImport(const QString &)));
 
@@ -88,7 +87,7 @@ int KGpgApp::newInstance()
 		connect(w, SIGNAL(createNewKey()), s_keyManager, SLOT(slotGenerateKey()));
 
 		if (!gpgPath.isEmpty()) {
-			if ((KgpgInterface::getGpgBoolSetting("use-agent", gpgPath)) && (qgetenv("GPG_AGENT_INFO").isEmpty()))
+			if ((KgpgInterface::getGpgBoolSetting(QLatin1String( "use-agent" ), gpgPath)) && (qgetenv("GPG_AGENT_INFO").isEmpty()))
 				KMessageBox::sorry(0, i18n("<qt>The use of <b>GnuPG Agent</b> is enabled in GnuPG's configuration file (%1).<br />"
 					"However, the agent does not seem to be running. This could result in problems with signing/decryption.<br />"
 					"Please disable GnuPG Agent from KGpg settings, or fix the agent.</qt>", gpgPath));
@@ -97,9 +96,6 @@ int KGpgApp::newInstance()
 
 	args = KCmdLineArgs::parsedArgs();
 
-	goHome = qobject_cast<KAction *>(s_keyManager->actionCollection()->action("go_default_key"))->shortcut();
-	w->goDefaultKey = goHome;
-
 	// parsing of command line args
 	if (args->isSet("k") || (!KGpgSettings::showSystray() && (args->count() == 0) && !args->isSet("d"))) {
 		s_keyManager->show();
@@ -122,7 +118,7 @@ int KGpgApp::newInstance()
 		bool directoryInside = false;
 		const QStringList lst = urlList.toStringList();
 		for (QStringList::const_iterator it = lst.begin(); it != lst.end(); ++it)
-			if (KMimeType::findByUrl(KUrl(*it))->name() == "inode/directory")
+			if (KMimeType::findByUrl(KUrl(*it))->name() == QLatin1String( "inode/directory" ))
 				directoryInside = true;
 
 		if ((directoryInside) && (lst.count() > 1)) {
@@ -153,19 +149,20 @@ int KGpgApp::newInstance()
 			else
 				KMessageBox::sorry(0, i18n("Cannot verify folder."));
 		} else {
-			if (w->droppedUrl.fileName().endsWith(".sig")) {
+			if (w->droppedUrl.fileName().endsWith(QLatin1String(".sig"))) {
 				w->slotVerifyFile();
 			} else {
 				bool haskeys = false;
 				bool hastext = false;
-				foreach (const KUrl url, urlList) {
+				foreach (const KUrl &url, urlList) {
 					QFile qfile(url.path());
 					if (qfile.open(QIODevice::ReadOnly)) {
+						const int probelen = 4096;
 						QTextStream t(&qfile);
-						QString result(t.read(1024));
+						QString probetext(t.read(probelen));
 						qfile.close();
 
-						if (KgpgTextEdit::checkForKey(result))
+						if (KGpgImport::isKey(probetext, probetext.length() == probelen))
 							haskeys = true;
 						else
 							hastext = true;
