@@ -33,6 +33,8 @@ class KFontChooser;
 class KConfig;
 
 class Encryption;
+class KGpgItemModel;
+class KeyListProxyModel;
 
 class Decryption : public QWidget, public Ui::Decryption
 {
@@ -82,7 +84,7 @@ class kgpgOptions : public KConfigDialog
     Q_OBJECT
 
 public:
-    explicit kgpgOptions(QWidget *parent = 0, const char *name = 0);
+    explicit kgpgOptions(QWidget *parent = 0, KGpgItemModel *model = 0);
     ~kgpgOptions();
 
 signals:
@@ -119,11 +121,10 @@ private:
     QStringList names;
     QStringList ids;
     QString alwaysKeyID;
-    QString alwaysKeyName;
     QString fileEncryptionKey;
     QString gpgConfigPath;
     QString gpgBinPath;
-    QString keyServer;              // Server stored in gnupg config
+    QString keyServer;              // Server stored in GnuPG config
     QStringList serverList;         // Servers stored in kgpgrc
     QString defaultKeyServer;       // Default keyserver
     QStringList defaultServerList;  // Default list of servers including the default key server;
@@ -156,6 +157,10 @@ private:
     bool m_defaultencrypttoalways;
     bool m_showsystray;
     int m_trayaction;
+    int m_mailUats;
+
+    KGpgItemModel * const m_model;
+    KeyListProxyModel * const m_combomodel;
 };
 
 #endif // KGPGOPTIONS_H
